<!--
SPDX-FileCopyrightText: StorPool <support@storpool.com>
SPDX-License-Identifier: BSD-2-Clause
-->

# Changelog for sp-pkg, the StorPool internal OS packaging helper

## 1.1.0

- sp-pkg:
    - functionality:
        - do not ask for confirmation when replacing files in the repositories
        - read package definitions from the current branch, not only from
          the `master` one
        - RedHat-family distributions:
            - adapt to Mock 3.x: some chroot configuration filenames have changed
            - use AlmaLinux as the baseline for distribution version 8 or later
            - recognize CentOS Stream 9.x
            - allow for some variance in the Mock configuration and template files
            - use the new `pkg-builder-rpm` build host for remote builds
        - Debian-family distributions:
            - recognize Debian 12.x and Ubuntu 23.04
            - use the new `pkg-builder-deb` build host for remote builds
    - package metadata:
        - specify both lower and upper version constraints for dependencies,
          both for the installed package and in the test environments
        - declare Python 3.11 and 3.12 as supported versions
        - bump the sp-variant dependency to 3.x for CentOS 9.x support
        - drop the `setup_requires` setting, it was only needed for extracting
          the sp-pkg module's version, and `attr: ...` works by itself
        - move the lists of dependencies to separate `requirements/*.txt` files
        - move the package metadata to the `pyproject.toml` file
        - use the `defusedxml` library as per ruff's suggestion
        - switch from `setuptools` to `hatchling` for the PEP517 build
    - internals:
        - go back to using the internal `_SubparsersAction` class of
          the `argparse` library, since it differs between Python versions
        - fix some useless string concatenations
        - run the source through ruff's isort implementation
        - minor fixes and refactoring suggested by ruff
        - use deferred type annotations, hide some imports behind `TYPE_CHECKING`
        - use single assignment using `typing.Final` where possible
        - make the `defs.py` assertion about the builder metadata provide
          more information upon failure
        - add SPDX copyright and license tags
        - change some assertions to `if/sys.exit()` blocks so that they are
          certain to be checked regardless of Python startup options
- test suite:
    - mypy:
        - move the configuration settings to the `pyproject.toml` file
        - use mypy 1.x with no source code changes
        - do not pass the `python_version` option, check against
          the currently running Python interpreter's version
        - use `collections.abc.*` instead of `collections.*` for
          the classes that were moved there in Python 3.8
    - use black 23.x with no source code changes
    - separate options from positional arguments with `--` in Tox invocations
    - use pytest's fixtures and parametrization instead of unittest + ddt
    - add a ruff Tox test environment, pinning the Ruff version
    - add a Nix expression for running some Tox tests
    - add a reuse Tox test environment to validate our SPDX copyright and
      license tags
    - migrate the `tox.ini` file to the Tox 4.x format
    - drop the flake8 and pylint Tox test environments now that we use Ruff
    - rename the unit-tests-3 Tox test environment to unit-tests;
      this package never had any Python 2.x support at all

## 1.0.0

- sp-pkg:
    - incompatible change: drop support for CentOS 6 and Ubuntu 16.04
    - incompatible change: drop the old "branch list" command
    - incompatible change: rename the "branch list-known" command to
      "branch list"
    - incompatible change: only list branches that we know how to build for
      in the "branch list" output
    - specify a version for the sp-variant dependency to ensure support for
      Ubuntu 22.04 (Jammy Jellyfish)
    - settle on "sp-variant" as the spelling for the dependency specifications
    - import the correct module from sp-variant
    - drop an unneeded "..." in a method stub
    - add a fake build host for debian/unstable
    - add the --branch-only/-B option to the "chroot list" command
- Mention tox-delay in the README file.
- Drop the useless "basepython=python3" lines from the tox.ini file.
- Specify version 6 for the pytest dependency and drop the typing stub file.

## 0.7.0

- General Python style updates:
    - tox.ini: help pip out by adding a version to the hacking dependency
    - reformat the source code with 100 characters per line
    - use black 22 to format the source code
    - add Python 3.10 as a supported version
    - add a missed encoding parameter to a file open function
- General maintenance changes:
    - add an EditorConfig definitions file and fix a small nit in setup.cfg
    - add a shellcheck config file and fix a small nit in the internal wrapper
- sp-pkg:
    - Debian/Ubuntu:
        - add support for Ubuntu 21.10 (Impish Indri) and 22.04 (Jammy Jellyfish)
        - add support for building native packages, e.g. cgconfig-sysv
    - CentOS:
        - catch up with RPM's gpg-pubkey display format change
        - use CentOS Stream for the centos/8 chroot environment
- sp-replacerpm:
    - recognize RSA/SHA512 RPM signatures
    - add the -v command-line option
