# SPDX-FileCopyrightText: StorPool <support@storpool.com>
# SPDX-License-Identifier: BSD-2-Clause
"""Utility functions for the replace_rpm tests."""

from __future__ import annotations

import dataclasses
import pathlib
import typing

import utf8_locale

from sp_pkg import defs


if typing.TYPE_CHECKING:
    from typing import Final

    from sp_pkg.scan import rpm as s_rpm


@dataclasses.dataclass(frozen=True)
class BuiltRPMConfig:
    """Configuration settings and files prepared for testing."""

    t_built: s_rpm.RPMBuilt | None
    """The path to the previously-built `sp-hello` RPM files."""

    t_cfg: defs.Config
    """The `sp_pkg` configuration settings to use."""


def get_config() -> tuple[defs.Config, str]:
    """Set up the test configuration."""
    cfg: Final = defs.Config(
        branch=None,
        branch_only=False,
        mirror=None,
        path=defs.Paths(
            project=pathlib.Path(),
            package=pathlib.Path(),
            work=None,
            dist=pathlib.Path(),
            repo=pathlib.Path(),
            sprepo=pathlib.Path(),
            remote_sppkg=None,
        ),
        pkgname=None,
        subenv=utf8_locale.get_utf8_env(),
        verbose=True,
    )

    sp_hello: Final = cfg.subenv.get("SP_HELLO", "")

    return cfg, sp_hello


def create_empty_repo(cfg: defs.Config, repodir: pathlib.Path) -> None:
    """Create an empty repository."""
    (repodir / "SRPMS/Sources").mkdir(mode=0o755, parents=True)
    (repodir / "x86_64/Packages").mkdir(mode=0o755, parents=True)

    for sub in ("SRPMS", "x86_64"):
        print(f"- running createrepo_c on {repodir / sub}")
        cfg.check_call(["createrepo_c", "--", repodir / sub])
